Documentation
¶
Index ¶
- Variables
- func RegisterAgentHandler(s server.Server, hdlr AgentHandler, opts ...server.HandlerOption) error
- type AgentHandler
- type AgentService
- type Agent_StreamChatService
- type Agent_StreamChatStream
- type ChatRequest
- func (*ChatRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ChatRequest) GetMessage() string
- func (x *ChatRequest) GetParentId() string
- func (*ChatRequest) ProtoMessage()
- func (x *ChatRequest) ProtoReflect() protoreflect.Message
- func (x *ChatRequest) Reset()
- func (x *ChatRequest) String() string
- type ChatResponse
- func (*ChatResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ChatResponse) GetAgent() string
- func (x *ChatResponse) GetParentId() string
- func (x *ChatResponse) GetReply() string
- func (x *ChatResponse) GetRunId() string
- func (x *ChatResponse) GetToolCalls() []*ToolCall
- func (*ChatResponse) ProtoMessage()
- func (x *ChatResponse) ProtoReflect() protoreflect.Message
- func (x *ChatResponse) Reset()
- func (x *ChatResponse) String() string
- type ToolCall
- func (*ToolCall) Descriptor() ([]byte, []int)deprecated
- func (x *ToolCall) GetId() string
- func (x *ToolCall) GetInput() string
- func (x *ToolCall) GetName() string
- func (x *ToolCall) GetResult() string
- func (*ToolCall) ProtoMessage()
- func (x *ToolCall) ProtoReflect() protoreflect.Message
- func (x *ToolCall) Reset()
- func (x *ToolCall) String() string
Constants ¶
This section is empty.
Variables ¶
var File_agent_proto_agent_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAgentHandler ¶
func RegisterAgentHandler(s server.Server, hdlr AgentHandler, opts ...server.HandlerOption) error
Types ¶
type AgentHandler ¶
type AgentHandler interface {
Chat(context.Context, *ChatRequest, *ChatResponse) error
}
type AgentService ¶
type AgentService interface {
Chat(ctx context.Context, in *ChatRequest, opts ...client.CallOption) (*ChatResponse, error)
StreamChat(ctx context.Context, in *ChatRequest, opts ...client.CallOption) (Agent_StreamChatService, error)
}
func NewAgentService ¶
func NewAgentService(name string, c client.Client) AgentService
type Agent_StreamChatService ¶ added in v6.7.1
type Agent_StreamChatService interface {
Close() error
Recv() (*ChatResponse, error)
}
type Agent_StreamChatStream ¶ added in v6.7.1
type Agent_StreamChatStream interface {
Close() error
Send(*ChatResponse) error
Recv() (*ChatRequest, error)
}
type ChatRequest ¶
type ChatRequest struct {
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
// parent_id correlates this chat with the workflow or agent run that dispatched it.
ParentId string `protobuf:"bytes,2,opt,name=parent_id,json=parentId,proto3" json:"parent_id,omitempty"`
// contains filtered or unexported fields
}
func (*ChatRequest) Descriptor
deprecated
func (*ChatRequest) Descriptor() ([]byte, []int)
Deprecated: Use ChatRequest.ProtoReflect.Descriptor instead.
func (*ChatRequest) GetMessage ¶
func (x *ChatRequest) GetMessage() string
func (*ChatRequest) GetParentId ¶ added in v6.3.1
func (x *ChatRequest) GetParentId() string
func (*ChatRequest) ProtoMessage ¶
func (*ChatRequest) ProtoMessage()
func (*ChatRequest) ProtoReflect ¶
func (x *ChatRequest) ProtoReflect() protoreflect.Message
func (*ChatRequest) Reset ¶
func (x *ChatRequest) Reset()
func (*ChatRequest) String ¶
func (x *ChatRequest) String() string
type ChatResponse ¶
type ChatResponse struct {
Reply string `protobuf:"bytes,1,opt,name=reply,proto3" json:"reply,omitempty"`
Agent string `protobuf:"bytes,2,opt,name=agent,proto3" json:"agent,omitempty"`
ToolCalls []*ToolCall `protobuf:"bytes,3,rep,name=tool_calls,json=toolCalls,proto3" json:"tool_calls,omitempty"`
// run_id correlates this chat response with tool calls, traces, and run history.
RunId string `protobuf:"bytes,4,opt,name=run_id,json=runId,proto3" json:"run_id,omitempty"`
// parent_id is set when this response belongs to a delegated sub-agent run.
ParentId string `protobuf:"bytes,5,opt,name=parent_id,json=parentId,proto3" json:"parent_id,omitempty"`
// contains filtered or unexported fields
}
func (*ChatResponse) Descriptor
deprecated
func (*ChatResponse) Descriptor() ([]byte, []int)
Deprecated: Use ChatResponse.ProtoReflect.Descriptor instead.
func (*ChatResponse) GetAgent ¶
func (x *ChatResponse) GetAgent() string
func (*ChatResponse) GetParentId ¶ added in v6.3.1
func (x *ChatResponse) GetParentId() string
func (*ChatResponse) GetReply ¶
func (x *ChatResponse) GetReply() string
func (*ChatResponse) GetRunId ¶ added in v6.3.1
func (x *ChatResponse) GetRunId() string
func (*ChatResponse) GetToolCalls ¶
func (x *ChatResponse) GetToolCalls() []*ToolCall
func (*ChatResponse) ProtoMessage ¶
func (*ChatResponse) ProtoMessage()
func (*ChatResponse) ProtoReflect ¶
func (x *ChatResponse) ProtoReflect() protoreflect.Message
func (*ChatResponse) Reset ¶
func (x *ChatResponse) Reset()
func (*ChatResponse) String ¶
func (x *ChatResponse) String() string
type ToolCall ¶
type ToolCall struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Input string `protobuf:"bytes,3,opt,name=input,proto3" json:"input,omitempty"`
Result string `protobuf:"bytes,4,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*ToolCall) Descriptor
deprecated
func (*ToolCall) ProtoMessage ¶
func (*ToolCall) ProtoMessage()
func (*ToolCall) ProtoReflect ¶
func (x *ToolCall) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.